@@ -100,9 +100,10 @@ int buffer_size = 0;
 pid_t output_pid;
 /* Not used for the moment. It only works for CBR http/ftp retrieved files */
 extern http_file_length;
+#ifdef HAVE_ALSA
 /* ALSA Volume Range */
 extern long volume_min,volume_max;
-
+#endif
 /* Get the next frame in the round buffer */
 int getnext_place(int position)
 {
@@ -127,7 +128,9 @@ void *read_keyb(void *ptr)
 	if(options.opt & MPG321_ENABLE_BUFFER)
 	{
 //		init_alsa_volume_control("default");
+#ifdef HAVE_ALSA
 		bvolume = mpg321_alsa_get_volume();
+#endif
 		Decoded_Frames->timer = -1;
 	}
 	else
@@ -139,8 +142,10 @@ void *read_keyb(void *ptr)
 		{
 			if(options.opt & MPG321_ENABLE_BUFFER)
 			{
+#ifdef HAVE_ALSA
 				bvolume = mpg321_alsa_get_volume();
 				bvolume = bvolume - round(0.02*volume_max); /* 1dB decrement ? */
+#endif
 				Decoded_Frames->timer = 1;
 			}
 			else
@@ -150,9 +155,11 @@ void *read_keyb(void *ptr)
 			}
 			if(options.opt & MPG321_ENABLE_BUFFER)
 			{
+#ifdef HAVE_ALSA
 				if(bvolume < volume_min)
 					bvolume = volume_min;
 				Decoded_Frames->bvolume = 100*bvolume/volume_max;
+#endif
 			
 			}
 			else
@@ -161,23 +168,35 @@ void *read_keyb(void *ptr)
 					volume = 0;
 			}
 			if(options.opt & MPG321_ENABLE_BUFFER)
+			{	
+#ifdef HAVE_ALSA
 				mpg321_alsa_set_volume(bvolume);
+#endif
+			}
 			else
 				options.volume = mad_f_tofixed(volume / 100.0);
 			if(!(options.opt & MPG321_VERBOSE_PLAY))
 			{
+#ifdef HAVE_ALSA
 				if(options.opt & MPG321_ENABLE_BUFFER)
 					fprintf(stdout,"Volume: %lu%%      \r",100*bvolume/volume_max);
-				else
-					fprintf(stdout,"Volume: %ld%%      \r",volume);
+				else{
+#endif					
+					if(!(options.opt & MPG321_ENABLE_BUFFER))
+						fprintf(stdout,"Volume: %ld%%      \r",volume);
+#ifdef HAVE_ALSA
+				}
+#endif
 			}
 		}
 		if(ch == KEY_CTRL_VOLUME_UP)
 		{
 			if(options.opt & MPG321_ENABLE_BUFFER)
 			{
+#ifdef HAVE_ALSA
 				bvolume = mpg321_alsa_get_volume();
 				bvolume = bvolume + round(0.02*volume_max); /* 1dB increment? */
+#endif
 				Decoded_Frames->timer = 1;
 			}
 			else
@@ -187,9 +206,11 @@ void *read_keyb(void *ptr)
 			}
 			if(options.opt & MPG321_ENABLE_BUFFER)
 			{
+#ifdef HAVE_ALSA
 				if(bvolume > volume_max)
 					bvolume = volume_max;
 				Decoded_Frames->bvolume = 100*bvolume/volume_max;
+#endif
 			}
 			else
 			{
@@ -197,15 +218,25 @@ void *read_keyb(void *ptr)
 					volume = 100;
 			}
 			if(options.opt & MPG321_ENABLE_BUFFER)
+			{
+#ifdef HAVE_ALSA
 				mpg321_alsa_set_volume(bvolume);
+#endif
+			}
 			else
 				options.volume = mad_f_tofixed(volume / 100.0);
 			if(!(options.opt & MPG321_VERBOSE_PLAY))
 			{
+#ifdef HAVE_ALSA
 				if(options.opt & MPG321_ENABLE_BUFFER)
 					fprintf(stdout,"Volume: %lu%%      \r",100*bvolume/volume_max);
-				else
-					fprintf(stdout,"Volume: %ld%%      \r",volume);
+				else{
+#endif
+					if(!(options.opt & MPG321_ENABLE_BUFFER))
+						fprintf(stdout,"Volume: %ld%%      \r",volume);
+#ifdef HAVE_ALSA
+				}
+#endif
 			}
 		}
 		if(ch == KEY_CTRL_NEXT_SONG)
@@ -217,17 +248,21 @@ void *read_keyb(void *ptr)
 			if(!muted)
 			{
 				muted = 1;
+#ifdef HAVE_ALSA
 				if(options.opt & MPG321_ENABLE_BUFFER)
 					mpg321_alsa_set_volume((long)0.0);
 				else
+#endif
 					options.volume = mad_f_tofixed(0.0);
 			}
 			else
 			{
 				muted = 0;
+#ifdef HAVE_ALSA
 				if(options.opt & MPG321_ENABLE_BUFFER)
 					mpg321_alsa_set_volume(bvolume);
 				else
+#endif
 					options.volume = mad_f_tofixed(volume / 100.0);
 			}
 		}
@@ -334,9 +369,11 @@ void usage(char *argv0)
         "   --help or --longhelp     Print this help screen\n"
         "   --version or -V          Print version information\n"
         "Basic keys:                                            \n"
+	#ifdef HAVE_ALSA
 	"* or /   Increase or decrease volume.                  \n"
-	"n        Skip song.                                    \n"
 	"m        Mute/unmute                                   \n"
+	#endif
+	"n        Skip song.                                    \n"
 	"\n"
         "This version of mpg321 has been configured with " AUDIO_DEFAULT " as its default\n"
         "libao output device.\n" , argv0);
@@ -647,9 +684,11 @@ int main(int argc, char *argv[])
         printf ("@R MPG123\n");
 	if(options.opt & MPG321_ENABLE_BUFFER)
 	{
+#ifdef HAVE_ALSA
 		init_alsa_volume_control("default"); /* For the moment use "default", it works on most of the systems. Tested in Debian,Fedora,Ubuntu,RedHat,CentOS,Gentoo */
 		if(options.volume != MAD_F_ONE)
 			mpg321_alsa_set_volume((long)options.volume*volume_max/100);
+#endif
 	}
     }
 
@@ -672,9 +711,11 @@ int main(int argc, char *argv[])
 	    signal(SIGUSR1,handle_signals);
 	    if(!(options.opt & MPG321_REMOTE_PLAY))
 	    {
+#ifdef HAVE_ALSA
 		    init_alsa_volume_control("default");
 		    if(options.volume != MAD_F_ONE)
 			    mpg321_alsa_set_volume((long)options.volume*volume_max/100);
+#endif
 	    }
     }
 
